==> ph-schematron-api-8.0.0-sources.jar: com/helger/schematron/svrl/jaxb/ObjectFactory.java <==

package com.helger.schematron.svrl.jaxb;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.schematron.svrl.jaxb package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public static final QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.schematron.svrl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     the new instance of {@link SchematronOutputType } The created SchematronOutputType object and never <code>null</code>.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     the new instance of {@link NsPrefixInAttributeValues } The created NsPrefixInAttributeValues object and never <code>null</code>.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     the new instance of {@link ActivePattern } The created ActivePattern object and never <code>null</code>.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link Text }
     * 
     * @return
     *     the new instance of {@link Text } The created Text object and never <code>null</code>.
     */
    @Nonnull
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link RichText }
     * 
     * @return
     *     the new instance of {@link RichText } The created RichText object and never <code>null</code>.
     */
    @Nonnull
    public RichText createRichText() {
        return new RichText();
    }

    /**
     * Create an instance of {@link Dir }
     * 
     * @return
     *     the new instance of {@link Dir } The created Dir object and never <code>null</code>.
     */
    @Nonnull
    public Dir createDir() {
        return new Dir();
    }

    /**
     * Create an instance of {@link Span }
     * 
     * @return
     *     the new instance of {@link Span } The created Span object and never <code>null</code>.
     */
    @Nonnull
    public Span createSpan() {
        return new Span();
    }

    /**
     * Create an instance of {@link Emph }
     * 
     * @return
     *     the new instance of {@link Emph } The created Emph object and never <code>null</code>.
     */
    @Nonnull
    public Emph createEmph() {
        return new Emph();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     the new instance of {@link FiredRule } The created FiredRule object and never <code>null</code>.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     the new instance of {@link DiagnosticReference } The created DiagnosticReference object and never <code>null</code>.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     the new instance of {@link FailedAssert } The created FailedAssert object and never <code>null</code>.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link PropertyReference }
     * 
     * @return
     *     the new instance of {@link PropertyReference } The created PropertyReference object and never <code>null</code>.
     */
    @Nonnull
    public PropertyReference createPropertyReference() {
        return new PropertyReference();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     the new instance of {@link SuccessfulReport } The created SuccessfulReport object and never <code>null</code>.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

}

==> ph-schematron-api-8.0.6-sources.jar: com/helger/schematron/svrl/jaxb/ObjectFactory.java <==

package com.helger.schematron.svrl.jaxb;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.schematron.svrl.jaxb package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public static final QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");
    public static final QName _MessageCode_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "message-code");
    public static final QName _MessageCategory_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "message-category");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.schematron.svrl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     the new instance of {@link SchematronOutputType } The created SchematronOutputType object and never <code>null</code>.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     the new instance of {@link NsPrefixInAttributeValues } The created NsPrefixInAttributeValues object and never <code>null</code>.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     the new instance of {@link ActivePattern } The created ActivePattern object and never <code>null</code>.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link Text }
     * 
     * @return
     *     the new instance of {@link Text } The created Text object and never <code>null</code>.
     */
    @Nonnull
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link RichText }
     * 
     * @return
     *     the new instance of {@link RichText } The created RichText object and never <code>null</code>.
     */
    @Nonnull
    public RichText createRichText() {
        return new RichText();
    }

    /**
     * Create an instance of {@link Dir }
     * 
     * @return
     *     the new instance of {@link Dir } The created Dir object and never <code>null</code>.
     */
    @Nonnull
    public Dir createDir() {
        return new Dir();
    }

    /**
     * Create an instance of {@link Span }
     * 
     * @return
     *     the new instance of {@link Span } The created Span object and never <code>null</code>.
     */
    @Nonnull
    public Span createSpan() {
        return new Span();
    }

    /**
     * Create an instance of {@link Emph }
     * 
     * @return
     *     the new instance of {@link Emph } The created Emph object and never <code>null</code>.
     */
    @Nonnull
    public Emph createEmph() {
        return new Emph();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     the new instance of {@link FiredRule } The created FiredRule object and never <code>null</code>.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link SuppressedRule }
     * 
     * @return
     *     the new instance of {@link SuppressedRule } The created SuppressedRule object and never <code>null</code>.
     */
    @Nonnull
    public SuppressedRule createSuppressedRule() {
        return new SuppressedRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     the new instance of {@link DiagnosticReference } The created DiagnosticReference object and never <code>null</code>.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     the new instance of {@link FailedAssert } The created FailedAssert object and never <code>null</code>.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link PropertyReference }
     * 
     * @return
     *     the new instance of {@link PropertyReference } The created PropertyReference object and never <code>null</code>.
     */
    @Nonnull
    public PropertyReference createPropertyReference() {
        return new PropertyReference();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     the new instance of {@link SuccessfulReport } The created SuccessfulReport object and never <code>null</code>.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "message-code")
    @Nonnull
    public JAXBElement<String> createMessageCode(
        @Nullable
        final String value) {
        return new JAXBElement<>(_MessageCode_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "message-category")
    @Nonnull
    public JAXBElement<String> createMessageCategory(
        @Nullable
        final String value) {
        return new JAXBElement<>(_MessageCategory_QNAME, String.class, null, value);
    }

}
